pilas.atajos

Package pilas :: Module atajos |
[hide private]
[frames] | no frames]

# Module atajos

source code

Functions | [hide private]
crear_grupo(*k) Genera un grupo. | source code
definir_gravedad(x, y) Define la gravedad del motor de física. | source code
leer(texto) Utiliza el comando speak para 'leer' un texto como sonido. | source code
ocultar_puntero_del_mouse() Oculta el puntero del mouse. | source code
mostrar_puntero_del_mouse() Muestra el puntero del mouse. | source code
definir_modos(*k, **kv) Define los modos de depuración. | source code

Variables | [hide private]
| __package__ = ``'``pilas``'``

Function Details | [hide private]

### definir_gravedad(x, y) | source code
Define la gravedad del motor de física. :param x: Aceleración horizontal. :param y: Aceleración vertical.

### leer(texto) | source code
Utiliza el comando speak para 'leer' un texto como sonido. :param texto: Cadena de texto a pronunciar.